@@ -10,8 +10,8 @@ from .education_closures import EducationClosures
 from .education_enrolment import EducationEnrolment
 
 
-class TestScraperEducation:
-    def test_get_education(self, configuration, fallbacks):
+class TestScrapersCustom:
+    def test_get_custom(self, configuration, fallbacks):
         BaseScraper.population_lookup = dict()
         with Download(user_agent="test") as downloader:
             today_str = "2020-10-01"
@@ -269,3 +269,14 @@ class TestScraperEducation:
                 "education_enrolment",
                 "education_closures",
             ]
+
+            education_closures.add_hxltag_source("test", "#lala")
+            sources = education_closures.get_sources("test")
+            assert sources == [
+                (
+                    "#lala",
+                    "2020-10-01",
+                    "UNESCO",
+                    "https://data.humdata.org/dataset/global-school-closures-covid19",
+                )
+            ]
